pub struct FileMethods<'a, C, A>where
C: 'a,
A: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on file resources.
It is not used directly, but through the Drive hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_drive3 as drive3;
use std::default::Default;
use oauth2::{Authenticator, DefaultAuthenticatorDelegate, ApplicationSecret, MemoryStorage};
use drive3::Drive;
let secret: ApplicationSecret = Default::default();
let auth = Authenticator::new(&secret, DefaultAuthenticatorDelegate,
hyper::Client::with_connector(hyper::net::HttpsConnector::new(hyper_rustls::TlsClient::new())),
<MemoryStorage as Default>::default(), None);
let mut hub = Drive::new(hyper::Client::with_connector(hyper::net::HttpsConnector::new(hyper_rustls::TlsClient::new())), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `copy(...)`, `create(...)`, `delete(...)`, `empty_trash(...)`, `export(...)`, `generate_ids(...)`, `get(...)`, `list(...)`, `update(...)` and `watch(...)`
// to build up your call.
let rb = hub.files();Implementations
Sourceimpl<'a, C, A> FileMethods<'a, C, A>
impl<'a, C, A> FileMethods<'a, C, A>
Sourcepub fn watch(&self, request: Channel, file_id: &str) -> FileWatchCall<'a, C, A>
pub fn watch(&self, request: Channel, file_id: &str) -> FileWatchCall<'a, C, A>
Create a builder to help you perform the following task:
Subscribes to changes to a file
Arguments
request- No description provided.fileId- The ID of the file.
Sourcepub fn update(&self, request: File, file_id: &str) -> FileUpdateCall<'a, C, A>
pub fn update(&self, request: File, file_id: &str) -> FileUpdateCall<'a, C, A>
Create a builder to help you perform the following task:
Updates a file’s metadata and/or content with patch semantics.
Arguments
request- No description provided.fileId- The ID of the file.
Sourcepub fn export(&self, file_id: &str, mime_type: &str) -> FileExportCall<'a, C, A>
pub fn export(&self, file_id: &str, mime_type: &str) -> FileExportCall<'a, C, A>
Create a builder to help you perform the following task:
Exports a Google Doc to the requested MIME type and returns the exported content. Please note that the exported content is limited to 10MB.
Arguments
fileId- The ID of the file.mimeType- The MIME type of the format requested for this export.
Sourcepub fn copy(&self, request: File, file_id: &str) -> FileCopyCall<'a, C, A>
pub fn copy(&self, request: File, file_id: &str) -> FileCopyCall<'a, C, A>
Create a builder to help you perform the following task:
Creates a copy of a file and applies any requested updates with patch semantics.
Arguments
request- No description provided.fileId- The ID of the file.
Sourcepub fn empty_trash(&self) -> FileEmptyTrashCall<'a, C, A>
pub fn empty_trash(&self) -> FileEmptyTrashCall<'a, C, A>
Create a builder to help you perform the following task:
Permanently deletes all of the user’s trashed files.
Sourcepub fn list(&self) -> FileListCall<'a, C, A>
pub fn list(&self) -> FileListCall<'a, C, A>
Create a builder to help you perform the following task:
Lists or searches files.
Sourcepub fn generate_ids(&self) -> FileGenerateIdCall<'a, C, A>
pub fn generate_ids(&self) -> FileGenerateIdCall<'a, C, A>
Create a builder to help you perform the following task:
Generates a set of file IDs which can be provided in create requests.
Sourcepub fn create(&self, request: File) -> FileCreateCall<'a, C, A>
pub fn create(&self, request: File) -> FileCreateCall<'a, C, A>
Create a builder to help you perform the following task:
Creates a new file.
Arguments
request- No description provided.
Sourcepub fn delete(&self, file_id: &str) -> FileDeleteCall<'a, C, A>
pub fn delete(&self, file_id: &str) -> FileDeleteCall<'a, C, A>
Create a builder to help you perform the following task:
Permanently deletes a file owned by the user without moving it to the trash. If the file belongs to a Team Drive the user must be an organizer on the parent. If the target is a folder, all descendants owned by the user are also deleted.
Arguments
fileId- The ID of the file.
Sourcepub fn get(&self, file_id: &str) -> FileGetCall<'a, C, A>
pub fn get(&self, file_id: &str) -> FileGetCall<'a, C, A>
Create a builder to help you perform the following task:
Gets a file’s metadata or content by ID.
Arguments
fileId- The ID of the file.